.. _api_docs:

==================
API Documentation
==================

.. toctree::
   :maxdepth: 2
   :caption: GTNet

   Classification command <gtnet.classify>
   Predict command <gtnet.predict>
   Filter command <gtnet.filter>
   Utility functions <gtnet.utils>
   Full list of GTNet package contents <gtnet>


:ref:`modindex`
